@@ -39,6 +39,15 @@ public:
   explicit RrdaEncoder(const char* fileName, const char* key);
   ~RrdaEncoder(void);
 
+
+  /*!
+    \brief エラー文字列の取得
+
+    \retrun エラー文字列
+  */
+  const char* what(void) const;
+
+
   /*!
     \brief リソース名の一覧を返す
 
