@@ -9,13 +9,13 @@
   \todo エラーメッセージの処理
   \todo デジタル画像のコロンを最初に描画するように変更する
   \todo テーマファイルの絶対パスを格納するようにする
-  \todo 時刻毎のベース画像登録のあたりを実装する
+  \todo 時刻毎のベース画像表示処理を実装する
+  \todo アニメーション機能を付加する
 */
 
 #include <QLabel>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
-#include <QMap>
 #include <QPainter>
 #include <QRegion>
 #include <QBitmap>
